# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/eds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import endpoint_pb2 as envoy_dot_api_dot_v2_dot_endpoint__pb2

from envoy.api.v2.endpoint_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65nvoy/api/v2/eds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/endpoint.proto\"\n\n\x08\x45\x64sDummy2\xfa\x02\n\x18\x45ndpointDiscoveryService\x12X\n\x0fStreamEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x61\n\x0e\x44\x65ltaEndpoints\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12u\n\x0e\x46\x65tchEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v2/discovery:endpoints:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.api.v2.ClusterLoadAssignmentB\x8c\x01\n\x1aio.envoyproxy.envoy.api.v2B\x08\x45\x64sProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.eds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\010EdsProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\033\022\031envoy.service.endpoint.v3\272\200\310\321\006\002\020\001'
  _ENDPOINTDISCOVERYSERVICE._options = None
  _ENDPOINTDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007$\n\"envoy.api.v2.ClusterLoadAssignment'
  _ENDPOINTDISCOVERYSERVICE.methods_by_name['FetchEndpoints']._options = None
  _ENDPOINTDISCOVERYSERVICE.methods_by_name['FetchEndpoints']._serialized_options = b'\202\323\344\223\002\034\"\027/v2/discovery:endpoints:\001*'
  _globals['_EDSDUMMY']._serialized_start=226
  _globals['_EDSDUMMY']._serialized_end=236
  _globals['_ENDPOINTDISCOVERYSERVICE']._serialized_start=239
  _globals['_ENDPOINTDISCOVERYSERVICE']._serialized_end=617
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/http.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.tap.v3 import common_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/data/tap/v3/http.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1e\x65nvoy/data/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x98\x03\n\x11HttpBufferedTrace\x12=\n\x07request\x18\x01 \x01(\x0b\x32,.envoy.data.tap.v3.HttpBufferedTrace.Message\x12>\n\x08response\x18\x02 \x01(\x0b\x32,.envoy.data.tap.v3.HttpBufferedTrace.Message\x1a\xd2\x01\n\x07Message\x12\x32\n\x07headers\x18\x01 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue\x12%\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body\x12\x33\n\x08trailers\x18\x03 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue:7\x9a\xc5\x88\x1e\x32\n0envoy.data.tap.v2alpha.HttpBufferedTrace.Message:/\x9a\xc5\x88\x1e*\n(envoy.data.tap.v2alpha.HttpBufferedTrace\"\xd8\x03\n\x18HttpStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12:\n\x0frequest_headers\x18\x02 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00\x12\x35\n\x12request_body_chunk\x18\x03 \x01(\x0b\x32\x17.envoy.data.tap.v3.BodyH\x00\x12;\n\x10request_trailers\x18\x04 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00\x12;\n\x10response_headers\x18\x05 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00\x12\x36\n\x13response_body_chunk\x18\x06 \x01(\x0b\x32\x17.envoy.data.tap.v3.BodyH\x00\x12<\n\x11response_trailers\x18\x07 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMapH\x00:6\x9a\xc5\x88\x1e\x31\n/envoy.data.tap.v2alpha.HttpStreamedTraceSegmentB\x0f\n\rmessage_pieceBv\n\x1fio.envoyproxy.envoy.data.tap.v3B\tHttpProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v3.http_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.data.tap.v3B\tHttpProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _HTTPBUFFEREDTRACE_MESSAGE._options = None
  _HTTPBUFFEREDTRACE_MESSAGE._serialized_options = b'\232\305\210\0362\n0envoy.data.tap.v2alpha.HttpBufferedTrace.Message'
  _HTTPBUFFEREDTRACE._options = None
  _HTTPBUFFEREDTRACE._serialized_options = b'\232\305\210\036*\n(envoy.data.tap.v2alpha.HttpBufferedTrace'
  _HTTPSTREAMEDTRACESEGMENT._options = None
  _HTTPSTREAMEDTRACESEGMENT._serialized_options = b'\232\305\210\0361\n/envoy.data.tap.v2alpha.HttpStreamedTraceSegment'
  _globals['_HTTPBUFFEREDTRACE']._serialized_start=183
  _globals['_HTTPBUFFEREDTRACE']._serialized_end=591
  _globals['_HTTPBUFFEREDTRACE_MESSAGE']._serialized_start=332
  _globals['_HTTPBUFFEREDTRACE_MESSAGE']._serialized_end=542
  _globals['_HTTPSTREAMEDTRACESEGMENT']._serialized_start=594
  _globals['_HTTPSTREAMEDTRACESEGMENT']._serialized_end=1066
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/metrics/v3/metrics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/config/metrics/v3/metrics_service.proto\x12\x17\x65nvoy.config.metrics.v3\x1a(envoy/config/core/v3/config_source.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x88\x03\n\x14MetricsServiceConfig\x12\x41\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x03 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12=\n\x19report_counters_as_deltas\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x13\x65mit_tags_as_labels\x18\x04 \x01(\x08\x12Q\n\x13histogram_emit_mode\x18\x05 \x01(\x0e\x32*.envoy.config.metrics.v3.HistogramEmitModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:3\x9a\xc5\x88\x1e.\n,envoy.config.metrics.v2.MetricsServiceConfig*J\n\x11HistogramEmitMode\x12\x19\n\x15SUMMARY_AND_HISTOGRAM\x10\x00\x12\x0b\n\x07SUMMARY\x10\x01\x12\r\n\tHISTOGRAM\x10\x02\x42\x90\x01\n%io.envoyproxy.envoy.config.metrics.v3B\x13MetricsServiceProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/metrics/v3;metricsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.metrics.v3.metrics_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.metrics.v3B\023MetricsServiceProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/metrics/v3;metricsv3\272\200\310\321\006\002\020\002'
  _METRICSSERVICECONFIG.fields_by_name['grpc_service']._options = None
  _METRICSSERVICECONFIG.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _METRICSSERVICECONFIG.fields_by_name['transport_api_version']._options = None
  _METRICSSERVICECONFIG.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _METRICSSERVICECONFIG.fields_by_name['histogram_emit_mode']._options = None
  _METRICSSERVICECONFIG.fields_by_name['histogram_emit_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _METRICSSERVICECONFIG._options = None
  _METRICSSERVICECONFIG._serialized_options = b'\232\305\210\036.\n,envoy.config.metrics.v2.MetricsServiceConfig'
  _globals['_HISTOGRAMEMITMODE']._serialized_start=675
  _globals['_HISTOGRAMEMITMODE']._serialized_end=749
  _globals['_METRICSSERVICECONFIG']._serialized_start=281
  _globals['_METRICSSERVICECONFIG']._serialized_end=673
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.tap.v3 import common_pb2 as envoy_dot_config_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65nvoy/admin/v3/tap.proto\x12\x0e\x65nvoy.admin.v3\x1a envoy/config/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8d\x01\n\nTapRequest\x12\x1a\n\tconfig_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12<\n\ntap_config\x18\x02 \x01(\x0b\x32\x1e.envoy.config.tap.v3.TapConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.TapRequestBq\n\x1cio.envoyproxy.envoy.admin.v3B\x08TapProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.tap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\010TapProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _TAPREQUEST.fields_by_name['config_id']._options = None
  _TAPREQUEST.fields_by_name['config_id']._serialized_options = b'\372B\004r\002\020\001'
  _TAPREQUEST.fields_by_name['tap_config']._options = None
  _TAPREQUEST.fields_by_name['tap_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAPREQUEST._options = None
  _TAPREQUEST._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.TapRequest'
  _globals['_TAPREQUEST']._serialized_start=170
  _globals['_TAPREQUEST']._serialized_end=311
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rbac/audit_loggers/stream/v3/stream.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/rbac/audit_loggers/stream/v3/stream.proto\x12-envoy.extensions.rbac.audit_loggers.stream.v3\x1a\x1dudpa/annotations/status.proto\"\x10\n\x0eStdoutAuditLogB\xb3\x01\n;io.envoyproxy.envoy.extensions.rbac.audit_loggers.stream.v3B\x0bStreamProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rbac/audit_loggers/stream/v3;streamv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.rbac.audit_loggers.stream.v3.stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.rbac.audit_loggers.stream.v3B\013StreamProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rbac/audit_loggers/stream/v3;streamv3\272\200\310\321\006\002\020\002'
  _globals['_STDOUTAUDITLOG']._serialized_start=140
  _globals['_STDOUTAUDITLOG']._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/logging_metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import distribution_pb2 as google_dot_api_dot_distribution__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import metric_pb2 as google_dot_api_dot_metric__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'google/logging/v2/logging_metrics.proto\x12\x11google.logging.v2\x1a\x17google/api/client.proto\x1a\x1dgoogle/api/distribution.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x17google/api/metric.proto\x1a\x19google/api/resource.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\x95\x05\n\tLogMetric\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12=\n\x11metric_descriptor\x18\x05 \x01(\x0b\x32\x1c.google.api.MetricDescriptorB\x04\xe2\x41\x01\x01\x12\x1d\n\x0fvalue_extractor\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12Q\n\x10label_extractors\x18\x07 \x03(\x0b\x32\x31.google.logging.v2.LogMetric.LabelExtractorsEntryB\x04\xe2\x41\x01\x01\x12\x44\n\x0e\x62ucket_options\x18\x08 \x01(\x0b\x32&.google.api.Distribution.BucketOptionsB\x04\xe2\x41\x01\x01\x12\x35\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12<\n\x07version\x18\x04 \x01(\x0e\x32\'.google.logging.v2.LogMetric.ApiVersionB\x02\x18\x01\x1a\x36\n\x14LabelExtractorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\nApiVersion\x12\x06\n\x02V2\x10\x00\x12\x06\n\x02V1\x10\x01:J\xea\x41G\n logging.googleapis.com/LogMetric\x12#projects/{project}/metrics/{metric}\"\x90\x01\n\x15ListLogMetricsRequest\x12\x44\n\x06parent\x18\x01 \x01(\tB4\xe2\x41\x01\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x18\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"`\n\x16ListLogMetricsResponse\x12-\n\x07metrics\x18\x01 \x03(\x0b\x32\x1c.google.logging.v2.LogMetric\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"U\n\x13GetLogMetricRequest\x12>\n\x0bmetric_name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogMetric\"\x87\x01\n\x16\x43reateLogMetricRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 logging.googleapis.com/LogMetric\x12\x32\n\x06metric\x18\x02 \x01(\x0b\x32\x1c.google.logging.v2.LogMetricB\x04\xe2\x41\x01\x02\"\x8c\x01\n\x16UpdateLogMetricRequest\x12>\n\x0bmetric_name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogMetric\x12\x32\n\x06metric\x18\x02 \x01(\x0b\x32\x1c.google.logging.v2.LogMetricB\x04\xe2\x41\x01\x02\"X\n\x16\x44\x65leteLogMetricRequest\x12>\n\x0bmetric_name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogMetric2\xae\x08\n\x10MetricsServiceV2\x12\x97\x01\n\x0eListLogMetrics\x12(.google.logging.v2.ListLogMetricsRequest\x1a).google.logging.v2.ListLogMetricsResponse\"0\xda\x41\x06parent\x82\xd3\xe4\x93\x02!\x12\x1f/v2/{parent=projects/*}/metrics\x12\x92\x01\n\x0cGetLogMetric\x12&.google.logging.v2.GetLogMetricRequest\x1a\x1c.google.logging.v2.LogMetric\"<\xda\x41\x0bmetric_name\x82\xd3\xe4\x93\x02(\x12&/v2/{metric_name=projects/*/metrics/*}\x12\x9b\x01\n\x0f\x43reateLogMetric\x12).google.logging.v2.CreateLogMetricRequest\x1a\x1c.google.logging.v2.LogMetric\"?\xda\x41\rparent,metric\x82\xd3\xe4\x93\x02)\"\x1f/v2/{parent=projects/*}/metrics:\x06metric\x12\xa7\x01\n\x0fUpdateLogMetric\x12).google.logging.v2.UpdateLogMetricRequest\x1a\x1c.google.logging.v2.LogMetric\"K\xda\x41\x12metric_name,metric\x82\xd3\xe4\x93\x02\x30\x1a&/v2/{metric_name=projects/*/metrics/*}:\x06metric\x12\x92\x01\n\x0f\x44\x65leteLogMetric\x12).google.logging.v2.DeleteLogMetricRequest\x1a\x16.google.protobuf.Empty\"<\xda\x41\x0bmetric_name\x82\xd3\xe4\x93\x02(*&/v2/{metric_name=projects/*/metrics/*}\x1a\x8d\x02\xca\x41\x16logging.googleapis.com\xd2\x41\xf0\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.writeB\xbc\x01\n\x15\x63om.google.logging.v2B\x13LoggingMetricsProtoP\x01Z8google.golang.org/genproto/googleapis/logging/v2;logging\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2\xea\x02\x1aGoogle::Cloud::Logging::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.logging.v2.logging_metrics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.google.logging.v2B\023LoggingMetricsProtoP\001Z8google.golang.org/genproto/googleapis/logging/v2;logging\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2\352\002\032Google::Cloud::Logging::V2'
  _LOGMETRIC_LABELEXTRACTORSENTRY._options = None
  _LOGMETRIC_LABELEXTRACTORSENTRY._serialized_options = b'8\001'
  _LOGMETRIC.fields_by_name['name']._options = None
  _LOGMETRIC.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _LOGMETRIC.fields_by_name['description']._options = None
  _LOGMETRIC.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _LOGMETRIC.fields_by_name['filter']._options = None
  _LOGMETRIC.fields_by_name['filter']._serialized_options = b'\342A\001\002'
  _LOGMETRIC.fields_by_name['metric_descriptor']._options = None
  _LOGMETRIC.fields_by_name['metric_descriptor']._serialized_options = b'\342A\001\001'
  _LOGMETRIC.fields_by_name['value_extractor']._options = None
  _LOGMETRIC.fields_by_name['value_extractor']._serialized_options = b'\342A\001\001'
  _LOGMETRIC.fields_by_name['label_extractors']._options = None
  _LOGMETRIC.fields_by_name['label_extractors']._serialized_options = b'\342A\001\001'
  _LOGMETRIC.fields_by_name['bucket_options']._options = None
  _LOGMETRIC.fields_by_name['bucket_options']._serialized_options = b'\342A\001\001'
  _LOGMETRIC.fields_by_name['create_time']._options = None
  _LOGMETRIC.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _LOGMETRIC.fields_by_name['update_time']._options = None
  _LOGMETRIC.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _LOGMETRIC.fields_by_name['version']._options = None
  _LOGMETRIC.fields_by_name['version']._serialized_options = b'\030\001'
  _LOGMETRIC._options = None
  _LOGMETRIC._serialized_options = b'\352AG\n logging.googleapis.com/LogMetric\022#projects/{project}/metrics/{metric}'
  _LISTLOGMETRICSREQUEST.fields_by_name['parent']._options = None
  _LISTLOGMETRICSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A-\n+cloudresourcemanager.googleapis.com/Project'
  _LISTLOGMETRICSREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGMETRICSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTLOGMETRICSREQUEST.fields_by_name['page_size']._options = None
  _LISTLOGMETRICSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _GETLOGMETRICREQUEST.fields_by_name['metric_name']._options = None
  _GETLOGMETRICREQUEST.fields_by_name['metric_name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogMetric'
  _CREATELOGMETRICREQUEST.fields_by_name['parent']._options = None
  _CREATELOGMETRICREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 logging.googleapis.com/LogMetric'
  _CREATELOGMETRICREQUEST.fields_by_name['metric']._options = None
  _CREATELOGMETRICREQUEST.fields_by_name['metric']._serialized_options = b'\342A\001\002'
  _UPDATELOGMETRICREQUEST.fields_by_name['metric_name']._options = None
  _UPDATELOGMETRICREQUEST.fields_by_name['metric_name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogMetric'
  _UPDATELOGMETRICREQUEST.fields_by_name['metric']._options = None
  _UPDATELOGMETRICREQUEST.fields_by_name['metric']._serialized_options = b'\342A\001\002'
  _DELETELOGMETRICREQUEST.fields_by_name['metric_name']._options = None
  _DELETELOGMETRICREQUEST.fields_by_name['metric_name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogMetric'
  _METRICSSERVICEV2._options = None
  _METRICSSERVICEV2._serialized_options = b'\312A\026logging.googleapis.com\322A\360\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.write'
  _METRICSSERVICEV2.methods_by_name['ListLogMetrics']._options = None
  _METRICSSERVICEV2.methods_by_name['ListLogMetrics']._serialized_options = b'\332A\006parent\202\323\344\223\002!\022\037/v2/{parent=projects/*}/metrics'
  _METRICSSERVICEV2.methods_by_name['GetLogMetric']._options = None
  _METRICSSERVICEV2.methods_by_name['GetLogMetric']._serialized_options = b'\332A\013metric_name\202\323\344\223\002(\022&/v2/{metric_name=projects/*/metrics/*}'
  _METRICSSERVICEV2.methods_by_name['CreateLogMetric']._options = None
  _METRICSSERVICEV2.methods_by_name['CreateLogMetric']._serialized_options = b'\332A\rparent,metric\202\323\344\223\002)\"\037/v2/{parent=projects/*}/metrics:\006metric'
  _METRICSSERVICEV2.methods_by_name['UpdateLogMetric']._options = None
  _METRICSSERVICEV2.methods_by_name['UpdateLogMetric']._serialized_options = b'\332A\022metric_name,metric\202\323\344\223\0020\032&/v2/{metric_name=projects/*/metrics/*}:\006metric'
  _METRICSSERVICEV2.methods_by_name['DeleteLogMetric']._options = None
  _METRICSSERVICEV2.methods_by_name['DeleteLogMetric']._serialized_options = b'\332A\013metric_name\202\323\344\223\002(*&/v2/{metric_name=projects/*/metrics/*}'
  _globals['_LOGMETRIC']._serialized_start=362
  _globals['_LOGMETRIC']._serialized_end=1023
  _globals['_LOGMETRIC_LABELEXTRACTORSENTRY']._serialized_start=863
  _globals['_LOGMETRIC_LABELEXTRACTORSENTRY']._serialized_end=917
  _globals['_LOGMETRIC_APIVERSION']._serialized_start=919
  _globals['_LOGMETRIC_APIVERSION']._serialized_end=947
  _globals['_LISTLOGMETRICSREQUEST']._serialized_start=1026
  _globals['_LISTLOGMETRICSREQUEST']._serialized_end=1170
  _globals['_LISTLOGMETRICSRESPONSE']._serialized_start=1172
  _globals['_LISTLOGMETRICSRESPONSE']._serialized_end=1268
  _globals['_GETLOGMETRICREQUEST']._serialized_start=1270
  _globals['_GETLOGMETRICREQUEST']._serialized_end=1355
  _globals['_CREATELOGMETRICREQUEST']._serialized_start=1358
  _globals['_CREATELOGMETRICREQUEST']._serialized_end=1493
  _globals['_UPDATELOGMETRICREQUEST']._serialized_start=1496
  _globals['_UPDATELOGMETRICREQUEST']._serialized_end=1636
  _globals['_DELETELOGMETRICREQUEST']._serialized_start=1638
  _globals['_DELETELOGMETRICREQUEST']._serialized_end=1726
  _globals['_METRICSSERVICEV2']._serialized_start=1729
  _globals['_METRICSSERVICEV2']._serialized_end=2799
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/runtime/v3/rtds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/service/runtime/v3/rtds.proto\x12\x18\x65nvoy.service.runtime.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"8\n\tRtdsDummy:+\x9a\xc5\x88\x1e&\n$envoy.service.discovery.v2.RtdsDummy\"s\n\x07Runtime\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x05layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:)\x9a\xc5\x88\x1e$\n\"envoy.service.discovery.v2.Runtime2\xc4\x03\n\x17RuntimeDiscoveryService\x12r\n\rStreamRuntime\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12{\n\x0c\x44\x65ltaRuntime\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x8d\x01\n\x0c\x46\x65tchRuntime\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/discovery:runtime:\x01*\x1a(\x8a\xa4\x96\xf3\x07\"\n envoy.service.runtime.v3.RuntimeB\x88\x01\n&io.envoyproxy.envoy.service.runtime.v3B\tRtdsProtoP\x01ZIgithub.com/envoyproxy/go-control-plane/envoy/service/runtime/v3;runtimev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.runtime.v3.rtds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.envoyproxy.envoy.service.runtime.v3B\tRtdsProtoP\001ZIgithub.com/envoyproxy/go-control-plane/envoy/service/runtime/v3;runtimev3\272\200\310\321\006\002\020\002'
  _RTDSDUMMY._options = None
  _RTDSDUMMY._serialized_options = b'\232\305\210\036&\n$envoy.service.discovery.v2.RtdsDummy'
  _RUNTIME.fields_by_name['name']._options = None
  _RUNTIME.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _RUNTIME._options = None
  _RUNTIME._serialized_options = b'\232\305\210\036$\n\"envoy.service.discovery.v2.Runtime'
  _RUNTIMEDISCOVERYSERVICE._options = None
  _RUNTIMEDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007\"\n envoy.service.runtime.v3.Runtime'
  _RUNTIMEDISCOVERYSERVICE.methods_by_name['FetchRuntime']._options = None
  _RUNTIMEDISCOVERYSERVICE.methods_by_name['FetchRuntime']._serialized_options = b'\202\323\344\223\002\032\"\025/v3/discovery:runtime:\001*'
  _globals['_RTDSDUMMY']._serialized_start=294
  _globals['_RTDSDUMMY']._serialized_end=350
  _globals['_RUNTIME']._serialized_start=352
  _globals['_RUNTIME']._serialized_end=467
  _globals['_RUNTIMEDISCOVERYSERVICE']._serialized_start=470
  _globals['_RUNTIMEDISCOVERYSERVICE']._serialized_end=922
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/matching/v3/extension_matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.matcher.v3 import matcher_pb2 as envoy_dot_config_dot_common_dot_matcher_dot_v3_dot_matcher__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/common/matching/v3/extension_matcher.proto\x12#envoy.extensions.common.matching.v3\x1a,envoy/config/common/matcher/v3/matcher.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xea\x01\n\x14\x45xtensionWithMatcher\x12\x45\n\x07matcher\x18\x01 \x01(\x0b\x32\'.envoy.config.common.matcher.v3.MatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x31\n\x0bxds_matcher\x18\x03 \x01(\x0b\x32\x1c.xds.type.matcher.v3.Matcher\x12N\n\x10\x65xtension_config\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x42\xab\x01\n1io.envoyproxy.envoy.extensions.common.matching.v3B\x15\x45xtensionMatcherProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/matching/v3;matchingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.matching.v3.extension_matcher_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n1io.envoyproxy.envoy.extensions.common.matching.v3B\025ExtensionMatcherProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/matching/v3;matchingv3\272\200\310\321\006\002\020\002'
  _EXTENSIONWITHMATCHER.fields_by_name['matcher']._options = None
  _EXTENSIONWITHMATCHER.fields_by_name['matcher']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _EXTENSIONWITHMATCHER.fields_by_name['extension_config']._options = None
  _EXTENSIONWITHMATCHER.fields_by_name['extension_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTENSIONWITHMATCHER._options = None
  _EXTENSIONWITHMATCHER._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_EXTENSIONWITHMATCHER']._serialized_start=346
  _globals['_EXTENSIONWITHMATCHER']._serialized_end=580
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/dynamic_forward_proxy/v3/dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRenvoy/extensions/filters/http/dynamic_forward_proxy/v3/dynamic_forward_proxy.proto\x12\x36\x65nvoy.extensions.filters.http.dynamic_forward_proxy.v3\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdb\x02\n\x0c\x46ilterConfig\x12\\\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigH\x00\x12\x66\n\x12sub_cluster_config\x18\x03 \x01(\x0b\x32H.envoy.extensions.filters.http.dynamic_forward_proxy.v3.SubClusterConfigH\x00\x12\x1d\n\x15save_upstream_address\x18\x02 \x01(\x08:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.FilterConfigB\x1a\n\x18implementation_specifier\"\xb7\x01\n\x0ePerRouteConfig\x12\x1e\n\x14host_rewrite_literal\x18\x01 \x01(\tH\x00\x12\x1d\n\x13host_rewrite_header\x18\x02 \x01(\tH\x00:L\x9a\xc5\x88\x1eG\nEenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.PerRouteConfigB\x18\n\x16host_rewrite_specifier\"U\n\x10SubClusterConfig\x12\x41\n\x14\x63luster_init_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x42\xe1\x01\nDio.envoyproxy.envoy.extensions.filters.http.dynamic_forward_proxy.v3B\x18\x44ynamicForwardProxyProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.dynamic_forward_proxy.v3.dynamic_forward_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.extensions.filters.http.dynamic_forward_proxy.v3B\030DynamicForwardProxyProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG._options = None
  _FILTERCONFIG._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.FilterConfig'
  _PERROUTECONFIG._options = None
  _PERROUTECONFIG._serialized_options = b'\232\305\210\036G\nEenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.PerRouteConfig'
  _SUBCLUSTERCONFIG.fields_by_name['cluster_init_timeout']._options = None
  _SUBCLUSTERCONFIG.fields_by_name['cluster_init_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_FILTERCONFIG']._serialized_start=332
  _globals['_FILTERCONFIG']._serialized_end=679
  _globals['_PERROUTECONFIG']._serialized_start=682
  _globals['_PERROUTECONFIG']._serialized_end=865
  _globals['_SUBCLUSTERCONFIG']._serialized_start=867
  _globals['_SUBCLUSTERCONFIG']._serialized_end=952
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2

from envoy.api.v2.listener.listener_components_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/api/v2/listener/listener.proto\x12\x15\x65nvoy.api.v2.listener\x1a/envoy/api/v2/listener/listener_components.protoB\xab\x01\n#io.envoyproxy.envoy.api.v2.listenerB\rListenerProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x1a\x45nvoy::Api::V2::ListenerNSP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.listener.listener_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.listenerB\rListenerProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\252\002\027Envoy.Api.V2.ListenerNS\352\002\032Envoy::Api::V2::ListenerNS'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/kafka_broker/v2alpha1/kafka_broker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/config/filter/network/kafka_broker/v2alpha1/kafka_broker.proto\x12\x31\x65nvoy.config.filter.network.kafka_broker.v2alpha1\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"+\n\x0bKafkaBroker\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\xef\x01\n?io.envoyproxy.envoy.config.filter.network.kafka_broker.v2alpha1B\x10KafkaBrokerProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/kafka_broker/v2alpha1\xf2\x98\xfe\x8f\x05\x32\x12\x30\x65nvoy.extensions.filters.network.kafka_broker.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.kafka_broker.v2alpha1.kafka_broker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.config.filter.network.kafka_broker.v2alpha1B\020KafkaBrokerProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/kafka_broker/v2alpha1\362\230\376\217\0052\0220envoy.extensions.filters.network.kafka_broker.v3\272\200\310\321\006\002\020\001'
  _KAFKABROKER.fields_by_name['stat_prefix']._options = None
  _KAFKABROKER.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _globals['_KAFKABROKER']._serialized_start=211
  _globals['_KAFKABROKER']._serialized_end=254
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/matcher/v3/ip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.core.v3 import cidr_pb2 as xds_dot_core_dot_v3_dot_cidr__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cxds/type/matcher/v3/ip.proto\x12\x13xds.type.matcher.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x16xds/core/v3/cidr.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x17validate/validate.proto\"\xe2\x01\n\tIPMatcher\x12\x45\n\x0erange_matchers\x18\x01 \x03(\x0b\x32-.xds.type.matcher.v3.IPMatcher.IPRangeMatcher\x1a\x8d\x01\n\x0eIPRangeMatcher\x12\x30\n\x06ranges\x18\x01 \x03(\x0b\x32\x16.xds.core.v3.CidrRangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x08on_match\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatch\x12\x11\n\texclusive\x18\x03 \x01(\x08\x42\x66\n\x1e\x63om.github.xds.type.matcher.v3B\x0eIPMatcherProtoP\x01Z*github.com/cncf/xds/go/xds/type/matcher/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.matcher.v3.ip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.type.matcher.v3B\016IPMatcherProtoP\001Z*github.com/cncf/xds/go/xds/type/matcher/v3\322\306\244\341\006\002\010\001'
  _IPMATCHER_IPRANGEMATCHER.fields_by_name['ranges']._options = None
  _IPMATCHER_IPRANGEMATCHER.fields_by_name['ranges']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_IPMATCHER']._serialized_start=171
  _globals['_IPMATCHER']._serialized_end=397
  _globals['_IPMATCHER_IPRANGEMATCHER']._serialized_start=256
  _globals['_IPMATCHER_IPRANGEMATCHER']._serialized_end=397
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import event_service_config_pb2 as envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2
from envoy.type import http_pb2 as envoy_dot_type_dot_http__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.type import range_pb2 as envoy_dot_type_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/api/v2/core/health_check.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a,envoy/api/v2/core/event_service_config.proto\x1a\x15\x65nvoy/type/http.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x16\x65nvoy/type/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x80\x12\n\x0bHealthCheck\x12\x36\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x37\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x31\n\x0einitial_jitter\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17interval_jitter_percent\x18\x12 \x01(\r\x12\x43\n\x13unhealthy_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x11healthy_threshold\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12.\n\x08\x61lt_port\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x10reuse_connection\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\x11http_health_check\x18\x08 \x01(\x0b\x32..envoy.api.v2.core.HealthCheck.HttpHealthCheckH\x00\x12I\n\x10tcp_health_check\x18\t \x01(\x0b\x32-.envoy.api.v2.core.HealthCheck.TcpHealthCheckH\x00\x12K\n\x11grpc_health_check\x18\x0b \x01(\x0b\x32..envoy.api.v2.core.HealthCheck.GrpcHealthCheckH\x00\x12O\n\x13\x63ustom_health_check\x18\r \x01(\x0b\x32\x30.envoy.api.v2.core.HealthCheck.CustomHealthCheckH\x00\x12@\n\x13no_traffic_interval\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12unhealthy_interval\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17unhealthy_edge_interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x42\n\x15healthy_edge_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x16\n\x0e\x65vent_log_path\x18\x11 \x01(\t\x12<\n\revent_service\x18\x16 \x01(\x0b\x32%.envoy.api.v2.core.EventServiceConfig\x12(\n always_log_health_check_failures\x18\x13 \x01(\x08\x12>\n\x0btls_options\x18\x15 \x01(\x0b\x32).envoy.api.v2.core.HealthCheck.TlsOptions\x1a\x44\n\x07Payload\x12\x17\n\x04text\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x10\n\x06\x62inary\x18\x02 \x01(\x0cH\x00\x42\x0e\n\x07payload\x12\x03\xf8\x42\x01\x1a\x86\x04\n\x0fHttpHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x04send\x18\x03 \x01(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x12\x37\n\x07receive\x18\x04 \x01(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x12\x18\n\x0cservice_name\x18\x05 \x01(\tB\x02\x18\x01\x12O\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12!\n\x19request_headers_to_remove\x18\x08 \x03(\t\x12\x1b\n\tuse_http2\x18\x07 \x01(\x08\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x31\n\x11\x65xpected_statuses\x18\t \x03(\x0b\x32\x16.envoy.type.Int64Range\x12@\n\x11\x63odec_client_type\x18\n \x01(\x0e\x32\x1b.envoy.type.CodecClientTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12?\n\x14service_name_matcher\x18\x0b \x01(\x0b\x32!.envoy.type.matcher.StringMatcher\x1a\x7f\n\x0eTcpHealthCheck\x12\x34\n\x04send\x18\x01 \x01(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x12\x37\n\x07receive\x18\x02 \x03(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x1a\x1f\n\x10RedisHealthCheck\x12\x0b\n\x03key\x18\x01 \x01(\t\x1a:\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t\x1a\x96\x01\n\x11\x43ustomHealthCheck\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a$\n\nTlsOptions\x12\x16\n\x0e\x61lpn_protocols\x18\x01 \x03(\tB\x15\n\x0ehealth_checker\x12\x03\xf8\x42\x01J\x04\x08\n\x10\x0b*`\n\x0cHealthStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x12\x0c\n\x08\x44RAINING\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x44\x45GRADED\x10\x05\x42\x93\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x10HealthCheckProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\020HealthCheckProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._options = None
  _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._serialized_options = b'\370B\001'
  _HEALTHCHECK_PAYLOAD.fields_by_name['text']._options = None
  _HEALTHCHECK_PAYLOAD.fields_by_name['text']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['service_name']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['service_name']._serialized_options = b'\030\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['use_http2']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['use_http2']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._options = None
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['config']._options = None
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['config']._serialized_options = b'\030\001'
  _HEALTHCHECK.oneofs_by_name['health_checker']._options = None
  _HEALTHCHECK.oneofs_by_name['health_checker']._serialized_options = b'\370B\001'
  _HEALTHCHECK.fields_by_name['timeout']._options = None
  _HEALTHCHECK.fields_by_name['timeout']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _HEALTHCHECK.fields_by_name['interval']._options = None
  _HEALTHCHECK.fields_by_name['interval']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['healthy_threshold']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK.fields_by_name['no_traffic_interval']._options = None
  _HEALTHCHECK.fields_by_name['no_traffic_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_interval']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['healthy_edge_interval']._options = None
  _HEALTHCHECK.fields_by_name['healthy_edge_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_HEALTHSTATUS']._serialized_start=2768
  _globals['_HEALTHSTATUS']._serialized_end=2864
  _globals['_HEALTHCHECK']._serialized_start=462
  _globals['_HEALTHCHECK']._serialized_end=2766
  _globals['_HEALTHCHECK_PAYLOAD']._serialized_start=1735
  _globals['_HEALTHCHECK_PAYLOAD']._serialized_end=1803
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_start=1806
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_end=2324
  _globals['_HEALTHCHECK_TCPHEALTHCHECK']._serialized_start=2326
  _globals['_HEALTHCHECK_TCPHEALTHCHECK']._serialized_end=2453
  _globals['_HEALTHCHECK_REDISHEALTHCHECK']._serialized_start=2455
  _globals['_HEALTHCHECK_REDISHEALTHCHECK']._serialized_end=2486
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_start=2488
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_end=2546
  _globals['_HEALTHCHECK_CUSTOMHEALTHCHECK']._serialized_start=2549
  _globals['_HEALTHCHECK_CUSTOMHEALTHCHECK']._serialized_end=2699
  _globals['_HEALTHCHECK_TLSOPTIONS']._serialized_start=2701
  _globals['_HEALTHCHECK_TLSOPTIONS']._serialized_end=2737
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/dynamic_forward_proxy/v2alpha/dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.dynamic_forward_proxy.v2alpha import dns_cache_pb2 as envoy_dot_config_dot_common_dot_dynamic__forward__proxy_dot_v2alpha_dot_dns__cache__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRenvoy/config/filter/http/dynamic_forward_proxy/v2alpha/dynamic_forward_proxy.proto\x12\x36\x65nvoy.config.filter.http.dynamic_forward_proxy.v2alpha\x1a\x41\x65nvoy/config/common/dynamic_forward_proxy/v2alpha/dns_cache.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"u\n\x0c\x46ilterConfig\x12\x65\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32\x41.envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xa1\x01\n\x0ePerRouteConfig\x12\x34\n\x0chost_rewrite\x18\x01 \x01(\tB\x1c\xf2\x98\xfe\x8f\x05\x16\n\x14host_rewrite_literalH\x00\x12?\n\x18\x61uto_host_rewrite_header\x18\x02 \x01(\tB\x1b\xf2\x98\xfe\x8f\x05\x15\n\x13host_rewrite_headerH\x00\x42\x18\n\x16host_rewrite_specifierB\x87\x02\nDio.envoyproxy.envoy.config.filter.http.dynamic_forward_proxy.v2alphaB\x18\x44ynamicForwardProxyProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/config/filter/http/dynamic_forward_proxy/v2alpha\xf2\x98\xfe\x8f\x05\x38\x12\x36\x65nvoy.extensions.filters.http.dynamic_forward_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.dynamic_forward_proxy.v2alpha.dynamic_forward_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.config.filter.http.dynamic_forward_proxy.v2alphaB\030DynamicForwardProxyProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/config/filter/http/dynamic_forward_proxy/v2alpha\362\230\376\217\0058\0226envoy.extensions.filters.http.dynamic_forward_proxy.v3\272\200\310\321\006\002\020\001'
  _FILTERCONFIG.fields_by_name['dns_cache_config']._options = None
  _FILTERCONFIG.fields_by_name['dns_cache_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PERROUTECONFIG.fields_by_name['host_rewrite']._options = None
  _PERROUTECONFIG.fields_by_name['host_rewrite']._serialized_options = b'\362\230\376\217\005\026\n\024host_rewrite_literal'
  _PERROUTECONFIG.fields_by_name['auto_host_rewrite_header']._options = None
  _PERROUTECONFIG.fields_by_name['auto_host_rewrite_header']._serialized_options = b'\362\230\376\217\005\025\n\023host_rewrite_header'
  _globals['_FILTERCONFIG']._serialized_start=297
  _globals['_FILTERCONFIG']._serialized_end=414
  _globals['_PERROUTECONFIG']._serialized_start=417
  _globals['_PERROUTECONFIG']._serialized_end=578
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/logging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.logging.v2 import log_entry_pb2 as google_dot_logging_dot_v2_dot_log__entry__pb2
from google.logging.v2 import logging_config_pb2 as google_dot_logging_dot_v2_dot_logging__config__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgoogle/logging/v2/logging.proto\x12\x11google.logging.v2\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a#google/api/monitored_resource.proto\x1a\x19google/api/resource.proto\x1a!google/logging/v2/log_entry.proto\x1a&google/logging/v2/logging_config.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a\x1cgoogle/api/annotations.proto\"I\n\x10\x44\x65leteLogRequest\x12\x35\n\x08log_name\x18\x01 \x01(\tB#\xe2\x41\x01\x02\xfa\x41\x1c\n\x1alogging.googleapis.com/Log\"\xec\x02\n\x16WriteLogEntriesRequest\x12\x35\n\x08log_name\x18\x01 \x01(\tB#\xe2\x41\x01\x01\xfa\x41\x1c\n\x1alogging.googleapis.com/Log\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.google.api.MonitoredResourceB\x04\xe2\x41\x01\x01\x12K\n\x06labels\x18\x03 \x03(\x0b\x32\x35.google.logging.v2.WriteLogEntriesRequest.LabelsEntryB\x04\xe2\x41\x01\x01\x12\x32\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x1b.google.logging.v2.LogEntryB\x04\xe2\x41\x01\x02\x12\x1d\n\x0fpartial_success\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x15\n\x07\x64ry_run\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x19\n\x17WriteLogEntriesResponse\"\xc8\x01\n\x1cWriteLogEntriesPartialErrors\x12]\n\x10log_entry_errors\x18\x01 \x03(\x0b\x32\x43.google.logging.v2.WriteLogEntriesPartialErrors.LogEntryErrorsEntry\x1aI\n\x13LogEntryErrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status:\x02\x38\x01\"\xb5\x01\n\x15ListLogEntriesRequest\x12;\n\x0eresource_names\x18\x08 \x03(\tB#\xe2\x41\x01\x02\xfa\x41\x1c\x12\x1alogging.googleapis.com/Log\x12\x14\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpage_size\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"_\n\x16ListLogEntriesResponse\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.google.logging.v2.LogEntry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\\\n\'ListMonitoredResourceDescriptorsRequest\x12\x17\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\"\x8a\x01\n(ListMonitoredResourceDescriptorsResponse\x12\x45\n\x14resource_descriptors\x18\x01 \x03(\x0b\x32\'.google.api.MonitoredResourceDescriptor\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x97\x01\n\x0fListLogsRequest\x12\x33\n\x06parent\x18\x01 \x01(\tB#\xe2\x41\x01\x02\xfa\x41\x1c\x12\x1alogging.googleapis.com/Log\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\x0eresource_names\x18\x08 \x03(\tB\x04\xe2\x41\x01\x01\">\n\x10ListLogsResponse\x12\x11\n\tlog_names\x18\x03 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x83\x01\n\x15TailLogEntriesRequest\x12\x1c\n\x0eresource_names\x18\x01 \x03(\tB\x04\xe2\x41\x01\x02\x12\x14\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\rbuffer_window\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe2\x41\x01\x01\"\xdf\x02\n\x16TailLogEntriesResponse\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.google.logging.v2.LogEntry\x12S\n\x10suppression_info\x18\x02 \x03(\x0b\x32\x39.google.logging.v2.TailLogEntriesResponse.SuppressionInfo\x1a\xc1\x01\n\x0fSuppressionInfo\x12P\n\x06reason\x18\x01 \x01(\x0e\x32@.google.logging.v2.TailLogEntriesResponse.SuppressionInfo.Reason\x12\x18\n\x10suppressed_count\x18\x02 \x01(\x05\"B\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x0e\n\nRATE_LIMIT\x10\x01\x12\x10\n\x0cNOT_CONSUMED\x10\x02\x32\xe6\x0b\n\x10LoggingServiceV2\x12\x93\x02\n\tDeleteLog\x12#.google.logging.v2.DeleteLogRequest\x1a\x16.google.protobuf.Empty\"\xc8\x01\xda\x41\x08log_name\x82\xd3\xe4\x93\x02\xb6\x01* /v2/{log_name=projects/*/logs/*}Z\x1b*\x19/v2/{log_name=*/*/logs/*}Z\'*%/v2/{log_name=organizations/*/logs/*}Z!*\x1f/v2/{log_name=folders/*/logs/*}Z)*\'/v2/{log_name=billingAccounts/*/logs/*}\x12\xa9\x01\n\x0fWriteLogEntries\x12).google.logging.v2.WriteLogEntriesRequest\x1a*.google.logging.v2.WriteLogEntriesResponse\"?\xda\x41 log_name,resource,labels,entries\x82\xd3\xe4\x93\x02\x16\"\x11/v2/entries:write:\x01*\x12\xa3\x01\n\x0eListLogEntries\x12(.google.logging.v2.ListLogEntriesRequest\x1a).google.logging.v2.ListLogEntriesResponse\"<\xda\x41\x1eresource_names,filter,order_by\x82\xd3\xe4\x93\x02\x15\"\x10/v2/entries:list:\x01*\x12\xc5\x01\n ListMonitoredResourceDescriptors\x12:.google.logging.v2.ListMonitoredResourceDescriptorsRequest\x1a;.google.logging.v2.ListMonitoredResourceDescriptorsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v2/monitoredResourceDescriptors\x12\x88\x02\n\x08ListLogs\x12\".google.logging.v2.ListLogsRequest\x1a#.google.logging.v2.ListLogsResponse\"\xb2\x01\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xa2\x01\x12\x15/v2/{parent=*/*}/logsZ\x1e\x12\x1c/v2/{parent=projects/*}/logsZ#\x12!/v2/{parent=organizations/*}/logsZ\x1d\x12\x1b/v2/{parent=folders/*}/logsZ%\x12#/v2/{parent=billingAccounts/*}/logs\x12\x86\x01\n\x0eTailLogEntries\x12(.google.logging.v2.TailLogEntriesRequest\x1a).google.logging.v2.TailLogEntriesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v2/entries:tail:\x01*(\x01\x30\x01\x1a\x8d\x02\xca\x41\x16logging.googleapis.com\xd2\x41\xf0\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.writeB\xb5\x01\n\x15\x63om.google.logging.v2B\x0cLoggingProtoP\x01Z8google.golang.org/genproto/googleapis/logging/v2;logging\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2\xea\x02\x1aGoogle::Cloud::Logging::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.logging.v2.logging_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.google.logging.v2B\014LoggingProtoP\001Z8google.golang.org/genproto/googleapis/logging/v2;logging\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2\352\002\032Google::Cloud::Logging::V2'
  _DELETELOGREQUEST.fields_by_name['log_name']._options = None
  _DELETELOGREQUEST.fields_by_name['log_name']._serialized_options = b'\342A\001\002\372A\034\n\032logging.googleapis.com/Log'
  _WRITELOGENTRIESREQUEST_LABELSENTRY._options = None
  _WRITELOGENTRIESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['log_name']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['log_name']._serialized_options = b'\342A\001\001\372A\034\n\032logging.googleapis.com/Log'
  _WRITELOGENTRIESREQUEST.fields_by_name['resource']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['resource']._serialized_options = b'\342A\001\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['labels']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['labels']._serialized_options = b'\342A\001\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['entries']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['entries']._serialized_options = b'\342A\001\002'
  _WRITELOGENTRIESREQUEST.fields_by_name['partial_success']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['partial_success']._serialized_options = b'\342A\001\001'
  _WRITELOGENTRIESREQUEST.fields_by_name['dry_run']._options = None
  _WRITELOGENTRIESREQUEST.fields_by_name['dry_run']._serialized_options = b'\342A\001\001'
  _WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY._options = None
  _WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY._serialized_options = b'8\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['resource_names']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['resource_names']._serialized_options = b'\342A\001\002\372A\034\022\032logging.googleapis.com/Log'
  _LISTLOGENTRIESREQUEST.fields_by_name['filter']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['order_by']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['page_size']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTLOGENTRIESREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGENTRIESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_size']._options = None
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_token']._options = None
  _LISTMONITOREDRESOURCEDESCRIPTORSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTLOGSREQUEST.fields_by_name['parent']._options = None
  _LISTLOGSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\034\022\032logging.googleapis.com/Log'
  _LISTLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTLOGSREQUEST.fields_by_name['resource_names']._options = None
  _LISTLOGSREQUEST.fields_by_name['resource_names']._serialized_options = b'\342A\001\001'
  _TAILLOGENTRIESREQUEST.fields_by_name['resource_names']._options = None
  _TAILLOGENTRIESREQUEST.fields_by_name['resource_names']._serialized_options = b'\342A\001\002'
  _TAILLOGENTRIESREQUEST.fields_by_name['filter']._options = None
  _TAILLOGENTRIESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _TAILLOGENTRIESREQUEST.fields_by_name['buffer_window']._options = None
  _TAILLOGENTRIESREQUEST.fields_by_name['buffer_window']._serialized_options = b'\342A\001\001'
  _LOGGINGSERVICEV2._options = None
  _LOGGINGSERVICEV2._serialized_options = b'\312A\026logging.googleapis.com\322A\360\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read,https://www.googleapis.com/auth/logging.write'
  _LOGGINGSERVICEV2.methods_by_name['DeleteLog']._options = None
  _LOGGINGSERVICEV2.methods_by_name['DeleteLog']._serialized_options = b'\332A\010log_name\202\323\344\223\002\266\001* /v2/{log_name=projects/*/logs/*}Z\033*\031/v2/{log_name=*/*/logs/*}Z\'*%/v2/{log_name=organizations/*/logs/*}Z!*\037/v2/{log_name=folders/*/logs/*}Z)*\'/v2/{log_name=billingAccounts/*/logs/*}'
  _LOGGINGSERVICEV2.methods_by_name['WriteLogEntries']._options = None
  _LOGGINGSERVICEV2.methods_by_name['WriteLogEntries']._serialized_options = b'\332A log_name,resource,labels,entries\202\323\344\223\002\026\"\021/v2/entries:write:\001*'
  _LOGGINGSERVICEV2.methods_by_name['ListLogEntries']._options = None
  _LOGGINGSERVICEV2.methods_by_name['ListLogEntries']._serialized_options = b'\332A\036resource_names,filter,order_by\202\323\344\223\002\025\"\020/v2/entries:list:\001*'
  _LOGGINGSERVICEV2.methods_by_name['ListMonitoredResourceDescriptors']._options = None
  _LOGGINGSERVICEV2.methods_by_name['ListMonitoredResourceDescriptors']._serialized_options = b'\202\323\344\223\002\"\022 /v2/monitoredResourceDescriptors'
  _LOGGINGSERVICEV2.methods_by_name['ListLogs']._options = None
  _LOGGINGSERVICEV2.methods_by_name['ListLogs']._serialized_options = b'\332A\006parent\202\323\344\223\002\242\001\022\025/v2/{parent=*/*}/logsZ\036\022\034/v2/{parent=projects/*}/logsZ#\022!/v2/{parent=organizations/*}/logsZ\035\022\033/v2/{parent=folders/*}/logsZ%\022#/v2/{parent=billingAccounts/*}/logs'
  _LOGGINGSERVICEV2.methods_by_name['TailLogEntries']._options = None
  _LOGGINGSERVICEV2.methods_by_name['TailLogEntries']._serialized_options = b'\202\323\344\223\002\025\"\020/v2/entries:tail:\001*'
  _globals['_DELETELOGREQUEST']._serialized_start=434
  _globals['_DELETELOGREQUEST']._serialized_end=507
  _globals['_WRITELOGENTRIESREQUEST']._serialized_start=510
  _globals['_WRITELOGENTRIESREQUEST']._serialized_end=874
  _globals['_WRITELOGENTRIESREQUEST_LABELSENTRY']._serialized_start=829
  _globals['_WRITELOGENTRIESREQUEST_LABELSENTRY']._serialized_end=874
  _globals['_WRITELOGENTRIESRESPONSE']._serialized_start=876
  _globals['_WRITELOGENTRIESRESPONSE']._serialized_end=901
  _globals['_WRITELOGENTRIESPARTIALERRORS']._serialized_start=904
  _globals['_WRITELOGENTRIESPARTIALERRORS']._serialized_end=1104
  _globals['_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY']._serialized_start=1031
  _globals['_WRITELOGENTRIESPARTIALERRORS_LOGENTRYERRORSENTRY']._serialized_end=1104
  _globals['_LISTLOGENTRIESREQUEST']._serialized_start=1107
  _globals['_LISTLOGENTRIESREQUEST']._serialized_end=1288
  _globals['_LISTLOGENTRIESRESPONSE']._serialized_start=1290
  _globals['_LISTLOGENTRIESRESPONSE']._serialized_end=1385
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSREQUEST']._serialized_start=1387
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSREQUEST']._serialized_end=1479
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE']._serialized_start=1482
  _globals['_LISTMONITOREDRESOURCEDESCRIPTORSRESPONSE']._serialized_end=1620
  _globals['_LISTLOGSREQUEST']._serialized_start=1623
  _globals['_LISTLOGSREQUEST']._serialized_end=1774
  _globals['_LISTLOGSRESPONSE']._serialized_start=1776
  _globals['_LISTLOGSRESPONSE']._serialized_end=1838
  _globals['_TAILLOGENTRIESREQUEST']._serialized_start=1841
  _globals['_TAILLOGENTRIESREQUEST']._serialized_end=1972
  _globals['_TAILLOGENTRIESRESPONSE']._serialized_start=1975
  _globals['_TAILLOGENTRIESRESPONSE']._serialized_end=2326
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO']._serialized_start=2133
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO']._serialized_end=2326
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO_REASON']._serialized_start=2260
  _globals['_TAILLOGENTRIESRESPONSE_SUPPRESSIONINFO_REASON']._serialized_end=2326
  _globals['_LOGGINGSERVICEV2']._serialized_start=2329
  _globals['_LOGGINGSERVICEV2']._serialized_end=3839
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.event_reporting.v3 import event_reporting_service_pb2 as envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2


class EventReportingServiceStub(object):
    """[#protodoc-title: gRPC Event Reporting Service]

    [#not-implemented-hide:]
    Service for streaming different types of events from Envoy to a server. The examples of
    such events may be health check or outlier detection events.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamEvents = channel.stream_stream(
                '/envoy.service.event_reporting.v3.EventReportingService/StreamEvents',
                request_serializer=envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2.StreamEventsRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2.StreamEventsResponse.FromString,
                )


class EventReportingServiceServicer(object):
    """[#protodoc-title: gRPC Event Reporting Service]

    [#not-implemented-hide:]
    Service for streaming different types of events from Envoy to a server. The examples of
    such events may be health check or outlier detection events.
    """

    def StreamEvents(self, request_iterator, context):
        """Envoy will connect and send StreamEventsRequest messages forever.
        The management server may send StreamEventsResponse to configure event stream. See below.
        This API is designed for high throughput with the expectation that it might be lossy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventReportingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamEvents': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamEvents,
                    request_deserializer=envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2.StreamEventsRequest.FromString,
                    response_serializer=envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2.StreamEventsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.event_reporting.v3.EventReportingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventReportingService(object):
    """[#protodoc-title: gRPC Event Reporting Service]

    [#not-implemented-hide:]
    Service for streaming different types of events from Envoy to a server. The examples of
    such events may be health check or outlier detection events.
    """

    @staticmethod
    def StreamEvents(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.event_reporting.v3.EventReportingService/StreamEvents',
            envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2.StreamEventsRequest.SerializeToString,
            envoy_dot_service_dot_event__reporting_dot_v3_dot_event__reporting__service__pb2.StreamEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/dns/v3/dns_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/data/dns/v3/dns_table.proto\x12\x11\x65nvoy.data.dns.v3\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x93\x0b\n\x08\x44nsTable\x12%\n\x14\x65xternal_retry_count\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x03\x12\x45\n\x0fvirtual_domains\x18\x02 \x03(\x0b\x32,.envoy.data.dns.v3.DnsTable.DnsVirtualDomain\x12I\n\x0eknown_suffixes\x18\x03 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x1a\x62\n\x0b\x41\x64\x64ressList\x12\x1f\n\x07\x61\x64\x64ress\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02\x10\x03:2\x9a\xc5\x88\x1e-\n+envoy.data.dns.v2alpha.DnsTable.AddressList\x1a\x64\n\x12\x44nsServiceProtocol\x12\x1a\n\x06number\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x10\xff\x01H\x00\x12\x1a\n\x04name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x42\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xbe\x01\n\x10\x44nsServiceTarget\x12\x1f\n\thost_name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x12\"\n\x0c\x63luster_name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x12\x1b\n\x08priority\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x12\x19\n\x06weight\x18\x04 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x12\x17\n\x04port\x18\x05 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x42\x14\n\rendpoint_type\x12\x03\xf8\x42\x01\x1a\xed\x01\n\nDnsService\x12 \n\x0cservice_name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01\x12@\n\x08protocol\x18\x02 \x01(\x0b\x32..envoy.data.dns.v3.DnsTable.DnsServiceProtocol\x12\x32\n\x03ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12G\n\x07targets\x18\x04 \x03(\x0b\x32,.envoy.data.dns.v3.DnsTable.DnsServiceTargetB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aT\n\x0e\x44nsServiceList\x12\x42\n\x08services\x18\x01 \x03(\x0b\x32&.envoy.data.dns.v3.DnsTable.DnsServiceB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xf6\x01\n\x0b\x44nsEndpoint\x12?\n\x0c\x61\x64\x64ress_list\x18\x01 \x01(\x0b\x32\'.envoy.data.dns.v3.DnsTable.AddressListH\x00\x12\x16\n\x0c\x63luster_name\x18\x02 \x01(\tH\x00\x12\x42\n\x0cservice_list\x18\x03 \x01(\x0b\x32*.envoy.data.dns.v3.DnsTable.DnsServiceListH\x00:2\x9a\xc5\x88\x1e-\n+envoy.data.dns.v2alpha.DnsTable.DnsEndpointB\x16\n\x0f\x65ndpoint_config\x12\x03\xf8\x42\x01\x1a\xdb\x01\n\x10\x44nsVirtualDomain\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01\x12\x39\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32\'.envoy.data.dns.v3.DnsTable.DnsEndpoint\x12\x39\n\nanswer_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x1e:7\x9a\xc5\x88\x1e\x32\n0envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomain:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.data.dns.v2alpha.DnsTableBz\n\x1fio.envoyproxy.envoy.data.dns.v3B\rDnsTableProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/dns/v3;dnsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.dns.v3.dns_table_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.data.dns.v3B\rDnsTableProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/dns/v3;dnsv3\272\200\310\321\006\002\020\002'
  _DNSTABLE_ADDRESSLIST.fields_by_name['address']._options = None
  _DNSTABLE_ADDRESSLIST.fields_by_name['address']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002\020\003'
  _DNSTABLE_ADDRESSLIST._options = None
  _DNSTABLE_ADDRESSLIST._serialized_options = b'\232\305\210\036-\n+envoy.data.dns.v2alpha.DnsTable.AddressList'
  _DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']._options = None
  _DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number']._options = None
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number']._serialized_options = b'\372B\005*\003\020\377\001'
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name']._options = None
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']._options = None
  _DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['priority']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['priority']._serialized_options = b'\372B\006*\004\020\200\200\004'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['weight']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['weight']._serialized_options = b'\372B\006*\004\020\200\200\004'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['port']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['port']._serialized_options = b'\372B\006*\004\020\200\200\004'
  _DNSTABLE_DNSSERVICE.fields_by_name['service_name']._options = None
  _DNSTABLE_DNSSERVICE.fields_by_name['service_name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICE.fields_by_name['ttl']._options = None
  _DNSTABLE_DNSSERVICE.fields_by_name['ttl']._serialized_options = b'\372B\007\252\001\0042\002\010\001'
  _DNSTABLE_DNSSERVICE.fields_by_name['targets']._options = None
  _DNSTABLE_DNSSERVICE.fields_by_name['targets']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DNSTABLE_DNSSERVICELIST.fields_by_name['services']._options = None
  _DNSTABLE_DNSSERVICELIST.fields_by_name['services']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._options = None
  _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSENDPOINT._options = None
  _DNSTABLE_DNSENDPOINT._serialized_options = b'\232\305\210\036-\n+envoy.data.dns.v2alpha.DnsTable.DnsEndpoint'
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._serialized_options = b'\372B\007\252\001\0042\002\010\036'
  _DNSTABLE_DNSVIRTUALDOMAIN._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN._serialized_options = b'\232\305\210\0362\n0envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomain'
  _DNSTABLE.fields_by_name['external_retry_count']._options = None
  _DNSTABLE.fields_by_name['external_retry_count']._serialized_options = b'\372B\004*\002\030\003'
  _DNSTABLE.fields_by_name['known_suffixes']._options = None
  _DNSTABLE.fields_by_name['known_suffixes']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DNSTABLE._options = None
  _DNSTABLE._serialized_options = b'\232\305\210\036!\n\037envoy.data.dns.v2alpha.DnsTable'
  _globals['_DNSTABLE']._serialized_start=253
  _globals['_DNSTABLE']._serialized_end=1680
  _globals['_DNSTABLE_ADDRESSLIST']._serialized_start=450
  _globals['_DNSTABLE_ADDRESSLIST']._serialized_end=548
  _globals['_DNSTABLE_DNSSERVICEPROTOCOL']._serialized_start=550
  _globals['_DNSTABLE_DNSSERVICEPROTOCOL']._serialized_end=650
  _globals['_DNSTABLE_DNSSERVICETARGET']._serialized_start=653
  _globals['_DNSTABLE_DNSSERVICETARGET']._serialized_end=843
  _globals['_DNSTABLE_DNSSERVICE']._serialized_start=846
  _globals['_DNSTABLE_DNSSERVICE']._serialized_end=1083
  _globals['_DNSTABLE_DNSSERVICELIST']._serialized_start=1085
  _globals['_DNSTABLE_DNSSERVICELIST']._serialized_end=1169
  _globals['_DNSTABLE_DNSENDPOINT']._serialized_start=1172
  _globals['_DNSTABLE_DNSENDPOINT']._serialized_end=1418
  _globals['_DNSTABLE_DNSVIRTUALDOMAIN']._serialized_start=1421
  _globals['_DNSTABLE_DNSVIRTUALDOMAIN']._serialized_end=1640
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/sds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/discovery/v2/sds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\n\n\x08SdsDummy2\xe6\x02\n\x16SecretDiscoveryService\x12_\n\x0c\x44\x65ltaSecrets\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12V\n\rStreamSecrets\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12q\n\x0c\x46\x65tchSecrets\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v2/discovery:secrets:\x01*\x1a \x8a\xa4\x96\xf3\x07\x1a\n\x18\x65nvoy.api.v2.auth.SecretB\xac\x01\n(io.envoyproxy.envoy.service.discovery.v2B\x08SdsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.secret.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v2.sds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v2B\010SdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\362\230\376\217\005\031\022\027envoy.service.secret.v3\272\200\310\321\006\002\020\001'
  _SECRETDISCOVERYSERVICE._options = None
  _SECRETDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007\032\n\030envoy.api.v2.auth.Secret'
  _SECRETDISCOVERYSERVICE.methods_by_name['FetchSecrets']._options = None
  _SECRETDISCOVERYSERVICE.methods_by_name['FetchSecrets']._serialized_options = b'\202\323\344\223\002\032\"\025/v2/discovery:secrets:\001*'
  _globals['_SDSDUMMY']._serialized_start=225
  _globals['_SDSDUMMY']._serialized_end=235
  _globals['_SECRETDISCOVERYSERVICE']._serialized_start=238
  _globals['_SECRETDISCOVERYSERVICE']._serialized_end=596
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/filter_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(envoy/type/matcher/v3/filter_state.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"x\n\x12\x46ilterStateMatcher\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12<\n\x0cstring_match\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherH\x00\x42\x0e\n\x07matcher\x12\x03\xf8\x42\x01\x42\x89\x01\n#io.envoyproxy.envoy.type.matcher.v3B\x10\x46ilterStateProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.filter_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\020FilterStateProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _FILTERSTATEMATCHER.oneofs_by_name['matcher']._options = None
  _FILTERSTATEMATCHER.oneofs_by_name['matcher']._serialized_options = b'\370B\001'
  _FILTERSTATEMATCHER.fields_by_name['key']._options = None
  _FILTERSTATEMATCHER.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILTERSTATEMATCHER']._serialized_start=159
  _globals['_FILTERSTATEMATCHER']._serialized_end=279
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/retry/host/omit_canary_hosts/v3/omit_canary_hosts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/retry/host/omit_canary_hosts/v3/omit_canary_hosts.proto\x12\x30\x65nvoy.extensions.retry.host.omit_canary_hosts.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"c\n\x18OmitCanaryHostsPredicate:G\x9a\xc5\x88\x1e\x42\n@envoy.config.retry.omit_canary_hosts.v2.OmitCanaryHostsPredicateB\xcd\x01\n>io.envoyproxy.envoy.extensions.retry.host.omit_canary_hosts.v3B\x14OmitCanaryHostsProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/retry/host/omit_canary_hosts/v3;omit_canary_hostsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.retry.host.omit_canary_hosts.v3.omit_canary_hosts_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.retry.host.omit_canary_hosts.v3B\024OmitCanaryHostsProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/retry/host/omit_canary_hosts/v3;omit_canary_hostsv3\272\200\310\321\006\002\020\002'
  _OMITCANARYHOSTSPREDICATE._options = None
  _OMITCANARYHOSTSPREDICATE._serialized_options = b'\232\305\210\036B\n@envoy.config.retry.omit_canary_hosts.v2.OmitCanaryHostsPredicate'
  _globals['_OMITCANARYHOSTSPREDICATE']._serialized_start=192
  _globals['_OMITCANARYHOSTSPREDICATE']._serialized_end=291
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/composite/v3/composite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/composite/v3/composite.proto\x12*envoy.extensions.filters.http.composite.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\x15\n\tComposite:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\"W\n\x13\x45xecuteFilterAction\x12@\n\x0ctyped_config\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\xb3\x01\n8io.envoyproxy.envoy.extensions.filters.http.composite.v3B\x0e\x43ompositeProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/composite/v3;compositev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.composite.v3.composite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.composite.v3B\016CompositeProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/composite/v3;compositev3\272\200\310\321\006\002\020\002'
  _COMPOSITE._options = None
  _COMPOSITE._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_COMPOSITE']._serialized_start=208
  _globals['_COMPOSITE']._serialized_end=229
  _globals['_EXECUTEFILTERACTION']._serialized_start=231
  _globals['_EXECUTEFILTERACTION']._serialized_end=318
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/dns/v2alpha/dns_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/data/dns/v2alpha/dns_table.proto\x12\x16\x65nvoy.data.dns.v2alpha\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xfe\x03\n\x08\x44nsTable\x12\x1c\n\x14\x65xternal_retry_count\x18\x01 \x01(\r\x12T\n\x0fvirtual_domains\x18\x02 \x03(\x0b\x32\x31.envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomainB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x39\n\x0eknown_suffixes\x18\x03 \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x1a.\n\x0b\x41\x64\x64ressList\x12\x1f\n\x07\x61\x64\x64ress\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02\x10\x03\x1ak\n\x0b\x44nsEndpoint\x12\x44\n\x0c\x61\x64\x64ress_list\x18\x01 \x01(\x0b\x32,.envoy.data.dns.v2alpha.DnsTable.AddressListH\x00\x42\x16\n\x0f\x65ndpoint_config\x12\x03\xf8\x42\x01\x1a\xa5\x01\n\x10\x44nsVirtualDomain\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x02\xc0\x01\x01\x12>\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32,.envoy.data.dns.v2alpha.DnsTable.DnsEndpoint\x12\x37\n\nanswer_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x42\x80\x01\n$io.envoyproxy.envoy.data.dns.v2alphaB\rDnsTableProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/data/dns/v2alpha\xba\x80\xc8\xd1\x06\x04\x08\x01\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.dns.v2alpha.dns_table_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.data.dns.v2alphaB\rDnsTableProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/data/dns/v2alpha\272\200\310\321\006\004\010\001\020\001'
  _DNSTABLE_ADDRESSLIST.fields_by_name['address']._options = None
  _DNSTABLE_ADDRESSLIST.fields_by_name['address']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002\020\003'
  _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._options = None
  _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._serialized_options = b'\372B\007r\005\020\002\300\001\001'
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._serialized_options = b'\372B\005\252\001\002*\000'
  _DNSTABLE.fields_by_name['virtual_domains']._options = None
  _DNSTABLE.fields_by_name['virtual_domains']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_DNSTABLE']._serialized_start=188
  _globals['_DNSTABLE']._serialized_end=698
  _globals['_DNSTABLE_ADDRESSLIST']._serialized_start=375
  _globals['_DNSTABLE_ADDRESSLIST']._serialized_end=421
  _globals['_DNSTABLE_DNSENDPOINT']._serialized_start=423
  _globals['_DNSTABLE_DNSENDPOINT']._serialized_end=530
  _globals['_DNSTABLE_DNSVIRTUALDOMAIN']._serialized_start=533
  _globals['_DNSTABLE_DNSVIRTUALDOMAIN']._serialized_end=698
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/grpc_method_list.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(envoy/api/v2/core/grpc_method_list.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8f\x01\n\x0eGrpcMethodList\x12;\n\x08services\x18\x01 \x03(\x0b\x32).envoy.api.v2.core.GrpcMethodList.Service\x1a@\n\x07Service\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1e\n\x0cmethod_names\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x96\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x13GrpcMethodListProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.grpc_method_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\023GrpcMethodListProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _GRPCMETHODLIST_SERVICE.fields_by_name['name']._options = None
  _GRPCMETHODLIST_SERVICE.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _GRPCMETHODLIST_SERVICE.fields_by_name['method_names']._options = None
  _GRPCMETHODLIST_SERVICE.fields_by_name['method_names']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_GRPCMETHODLIST']._serialized_start=152
  _globals['_GRPCMETHODLIST']._serialized_end=295
  _globals['_GRPCMETHODLIST_SERVICE']._serialized_start=231
  _globals['_GRPCMETHODLIST_SERVICE']._serialized_end=295
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/filters/cel/v3/cel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/extensions/access_loggers/filters/cel/v3/cel.proto\x12.envoy.extensions.access_loggers.filters.cel.v3\x1a\x1dudpa/annotations/status.proto\"&\n\x10\x45xpressionFilter\x12\x12\n\nexpression\x18\x01 \x01(\tB\xaf\x01\n<io.envoyproxy.envoy.extensions.access_loggers.filters.cel.v3B\x08\x43\x65lProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/filters/cel/v3;celv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.filters.cel.v3.cel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.extensions.access_loggers.filters.cel.v3B\010CelProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/filters/cel/v3;celv3\272\200\310\321\006\002\020\002'
  _globals['_EXPRESSIONFILTER']._serialized_start=139
  _globals['_EXPRESSIONFILTER']._serialized_end=177
# @@protoc_insertion_point(module_scope)
